@@ -1,57 +1,55 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Annotation;
-{
-  $Config::Model::Annotation::VERSION = '2.047';
-}
-
-use Mouse ;
-use English ;
+$Config::Model::Annotation::VERSION = '2.059';
+use Mouse;
+use English;
 
 use File::Path;
-use IO::File ;
-use Data::Dumper ;
+use IO::File;
+use Data::Dumper;
+
 #use Log::Log4perl qw(get_logger :levels);
 
-use Config::Model::Exception ;
-use Config::Model::Node ;
+use Config::Model::Exception;
+use Config::Model::Node;
 use Config::Model::ObjTreeScanner;
 
 #use strict ;
 use Carp;
-#use warnings FATAL => qw(all);
 
+#use warnings FATAL => qw(all);
 
 use Carp qw/croak confess cluck/;
 
 #my $logger = get_logger("Annotation") ;
 
-
 has 'instance' => ( is => 'ro', isa => 'Config::Model::Instance', required => 1 );
-has 'config_class_name' => ( is => 'ro', isa => 'Str', required => 1 ) ;
-has 'file'     => ( is => 'ro', isa => 'Str', lazy =>1, builder => '_set_file' ) ;
-has 'dir'      => ( is => 'ro', isa => 'Str', lazy =>1, builder => '_set_dir' ) ;
-has 'root_dir'     => ( is => 'ro', isa => 'Str|Undef', default => '') ;
+has 'config_class_name' => ( is => 'ro', isa => 'Str', required => 1 );
+has 'file' => ( is => 'ro', isa => 'Str', lazy => 1, builder => '_set_file' );
+has 'dir' => ( is => 'ro', isa => 'Str', lazy => 1, builder => '_set_dir' );
+has 'root_dir' => ( is => 'ro', isa => 'Str|Undef', default => '' );
 
 sub _set_file {
-    my $self = shift ;
-    return $self->dir.$self->config_class_name . '-note.pl' ; 
+    my $self = shift;
+    return $self->dir . $self->config_class_name . '-note.pl';
 }
 
 sub _set_dir {
-    my $self = shift ;
-    my $dir = $self->root_dir ? $self->root_dir 
-             :  $EUID       ? "/var/lib/" 
-             :                "~/." ;
-    $dir .= "config-model/" ;
-    return $dir ;
+    my $self = shift;
+    my $dir =
+          $self->root_dir ? $self->root_dir
+        : $EUID           ? "/var/lib/"
+        :                   "~/.";
+    $dir .= "config-model/";
+    return $dir;
 }
 
 #sub new {
@@ -59,7 +57,7 @@ sub _set_dir {
 #    my $class = ref($proto) || $proto ;
 #    my $instance = shift ;
 #
-#    my $self 
+#    my $self
 #      = {
 #	 instance => $instance ,
 #	};
@@ -69,109 +67,105 @@ sub _set_dir {
 #}
 #
 
-
 sub save {
-    my $self = shift ;
+    my $self = shift;
 
-    my $dir = $self->dir ;
-    mkpath ($dir, { mode => 0755, verbose => 0}) unless -d $dir ;
-    my $h = $self->get_annotation_hash ;
-    my $data = Dumper($h) ;
-    my $io = IO::File->new($self->file, 'w',0644) 
-      || croak "Can't open $dir".$self->file.": $!";
-    print $io $data ;
-    $io->close ;
+    my $dir = $self->dir;
+    mkpath( $dir, { mode => 0755, verbose => 0 } ) unless -d $dir;
+    my $h    = $self->get_annotation_hash;
+    my $data = Dumper($h);
+    my $io   = IO::File->new( $self->file, 'w', 0644 )
+        || croak "Can't open $dir" . $self->file . ": $!";
+    print $io $data;
+    $io->close;
 }
 
 sub get_annotation_hash {
-    my $self = shift ;
+    my $self = shift;
 
-    my %data ;
-    my $scanner = Config::Model::ObjTreeScanner
-      ->new(
-	    leaf_cb         => \&my_leaf_cb ,
-	    hash_element_cb => \&my_hash_element_cb,
-	    list_element_cb => \&my_list_element_cb,
-	    node_element_cb => \&my_node_element_cb,
-	    fallback        => 'all',
-	   ) ;
-    my $root = $self->instance->config_root ;
+    my %data;
+    my $scanner = Config::Model::ObjTreeScanner->new(
+        leaf_cb         => \&my_leaf_cb,
+        hash_element_cb => \&my_hash_element_cb,
+        list_element_cb => \&my_list_element_cb,
+        node_element_cb => \&my_node_element_cb,
+        fallback        => 'all',
+    );
+    my $root = $self->instance->config_root;
 
-    $scanner->scan_node(\%data,$root) ;
-    return \%data ;
+    $scanner->scan_node( \%data, $root );
+    return \%data;
 }
 
 # WARNING: not a method
 sub my_hash_element_cb {
-    my ($scanner, $data_ref,$node,$element_name,@keys) = @_ ;
+    my ( $scanner, $data_ref, $node, $element_name, @keys ) = @_;
 
     # custom code using $data_ref
-    store_note_in_data($data_ref, $node->fetch_element($element_name) ) ;
+    store_note_in_data( $data_ref, $node->fetch_element($element_name) );
 
     # resume exploration
-    map {$scanner->scan_hash($data_ref,$node,$element_name,$_)} @keys ;
+    map { $scanner->scan_hash( $data_ref, $node, $element_name, $_ ) } @keys;
 }
 
 # WARNING: not a method
 sub my_node_element_cb {
-    my ($scanner, $data_ref,$node,$element_name,$key, $contained_node) = @_;
+    my ( $scanner, $data_ref, $node, $element_name, $key, $contained_node ) = @_;
 
     # your custom code using $data_ref
-    store_note_in_data($data_ref, $contained_node ) ;
+    store_note_in_data( $data_ref, $contained_node );
 
-    # explore next node 
-    $scanner->scan_node($data_ref,$contained_node);
+    # explore next node
+    $scanner->scan_node( $data_ref, $contained_node );
 }
 
 # WARNING: not a method
 sub my_list_element_cb {
-     my ($scanner, $data_ref,$node,$element_name,@idx) = @_ ;
+    my ( $scanner, $data_ref, $node, $element_name, @idx ) = @_;
 
-     # custom code using $data_ref
-    store_note_in_data($data_ref, $node->fetch_element($element_name) ) ;
+    # custom code using $data_ref
+    store_note_in_data( $data_ref, $node->fetch_element($element_name) );
 
     # resume exploration (if needed)
-     map {$scanner->scan_list($data_ref,$node,$element_name,$_)} @idx ;
-
-     # note: scan_list and scan_hash are equivalent
-  }
+    map { $scanner->scan_list( $data_ref, $node, $element_name, $_ ) } @idx;
 
+    # note: scan_list and scan_hash are equivalent
+}
 
 # WARNING: not a method
 sub my_leaf_cb {
-    my ($scanner, $data_ref,$node,$element_name,$index, $leaf_object) = @_ ;
-    store_note_in_data($data_ref, $leaf_object) ;
+    my ( $scanner, $data_ref, $node, $element_name, $index, $leaf_object ) = @_;
+    store_note_in_data( $data_ref, $leaf_object );
 }
 
 # WARNING: not a method
 sub store_note_in_data {
-    my ($data_ref,$obj) = @_ ;
+    my ( $data_ref, $obj ) = @_;
 
-    my $note = $obj -> annotation ;
-    return unless $note ;
-    
-    my $key = $obj -> location ;
-    $data_ref->{$key} = $note ;
+    my $note = $obj->annotation;
+    return unless $note;
+
+    my $key = $obj->location;
+    $data_ref->{$key} = $note;
 }
 
-
 sub load {
-    my $self = shift ;
-    my $f = $self->file ;
-    return unless -e $f ;
+    my $self = shift;
+    my $f    = $self->file;
+    return unless -e $f;
     my $hash = do $f || croak "can't do $f:$!";
-    my $root = $self->instance->config_root ;
+    my $root = $self->instance->config_root;
 
-    foreach my $path (keys %$hash ) {
-	my $obj = eval {$root ->grab(step => $path, autoadd => 0) } ;
-	next if $@ ; # skip annotation of unknown elements 
-	$obj->annotation($hash->{$path}) ;
+    foreach my $path ( keys %$hash ) {
+        my $obj = eval { $root->grab( step => $path, autoadd => 0 ) };
+        next if $@;    # skip annotation of unknown elements
+        $obj->annotation( $hash->{$path} );
     }
 }
 
-no Mouse ;
+no Mouse;
 
-__PACKAGE__ -> meta->make_immutable;
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -189,7 +183,7 @@ Config::Model::Annotation - Read and write configuration annotations
 
 =head1 VERSION
 
-version 2.047
+version 2.059
 
 =head1 SYNOPSIS
 
@@ -302,7 +296,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dominique Dumont.
+This software is Copyright (c) 2014 by Dominique Dumont.
 
 This is free software, licensed under:
 
