@@ -1,16 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Exception;
-{
-  $Config::Model::Exception::VERSION = '2.047';
-}
+$Config::Model::Exception::VERSION = '2.059';
 use warnings;
 use strict;
 use Data::Dumper;
@@ -51,12 +49,6 @@ use Exception::Class (
         fields      => [qw/object element info/],
     },
 
-    'Config::Model::Exception::RestrictedElement' => {
-        isa         => 'Config::Model::Exception::User',
-        description => 'restricted element',
-        fields      => [qw/object element level req_experience info/],
-    },
-
     'Config::Model::Exception::WrongType' => {
         isa         => 'Config::Model::Exception::User',
         description => 'wrong element type',
@@ -77,7 +69,7 @@ use Exception::Class (
     'Config::Model::Exception::UnknownElement' => {
         isa         => 'Config::Model::Exception::User',
         description => 'unknown element',
-        fields      => [qw/object min_experience element function where info/],
+        fields      => [qw/object element function where info/],
     },
 
     'Config::Model::Exception::AncestorClass' => {
@@ -88,7 +80,7 @@ use Exception::Class (
     'Config::Model::Exception::UnknownId' => {
         isa         => 'Config::Model::Exception::User',
         description => 'unknown identifier',
-        fields      => [qw/object min_experience element id function where/],
+        fields      => [qw/object element id function where/],
     },
 
     'Config::Model::Exception::WarpError' => {
@@ -138,17 +130,14 @@ use Exception::Class (
     },
 
     'Config::Model::Exception::XmlTree' =>
-      { description => 'error while parsing XML dump of a tree' },
+        { description => 'error while parsing XML dump of a tree' },
 
 );
 
 Config::Model::Exception::Internal->Trace(1);
 
 package Config::Model::Exception::Syntax;
-{
-  $Config::Model::Exception::Syntax::VERSION = '2.047';
-}
-
+$Config::Model::Exception::Syntax::VERSION = '2.059';
 sub full_message {
     my $self = shift;
 
@@ -162,10 +151,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::Any;
-{
-  $Config::Model::Exception::Any::VERSION = '2.047';
-}
-
+$Config::Model::Exception::Any::VERSION = '2.059';
 sub full_message {
     my $self = shift;
 
@@ -194,9 +180,7 @@ sub xpath_message {
 }
 
 package Config::Model::Exception::LoadData;
-{
-  $Config::Model::Exception::LoadData::VERSION = '2.047';
-}
+$Config::Model::Exception::LoadData::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
@@ -204,7 +188,7 @@ sub full_message {
     my $obj      = $self->object;
     my $location = defined $obj ? $obj->name : '';
     my $msg      = "Configuration item ";
-    $msg .= "'$location' " if $location;
+    $msg .= "'$location' "                             if $location;
     $msg .= "(class " . $obj->config_class_name . ") " if $obj->get_type eq 'node';
     $msg .= "has a " . $self->description;
     $msg .= ":\n\t" . $self->message . "\n";
@@ -214,9 +198,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::Model;
-{
-  $Config::Model::Exception::Model::VERSION = '2.047';
-}
+$Config::Model::Exception::Model::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
@@ -233,9 +215,9 @@ sub full_message {
             property => 'level'
         );
         $msg =
-            "In config class '"
-          . $obj->parent->config_class_name
-          . "', element '$element' (level $level) ";
+              "In config class '"
+            . $obj->parent->config_class_name
+            . "', element '$element' (level $level) ";
     }
     $msg .= "has a " . $self->description;
     $msg .= ":\n\t" . $self->message . "\n";
@@ -244,9 +226,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::Load;
-{
-  $Config::Model::Exception::Load::VERSION = '2.047';
-}
+$Config::Model::Exception::Load::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
@@ -255,9 +235,9 @@ sub full_message {
     my $msg      = $self->description;
     my $cmd      = $self->command;
     my $cmd_str =
-        defined $cmd && $cmd ? "'$cmd'"
-      : defined $cmd ? '<empty>'
-      :                '<undef>';
+          defined $cmd && $cmd ? "'$cmd'"
+        : defined $cmd ? '<empty>'
+        :                '<undef>';
     $msg .= " in node '$location'" if $location;
     $msg .= ':';
     $msg .= "\n\tcommand: $cmd_str";
@@ -266,28 +246,8 @@ sub full_message {
     return $msg;
 }
 
-package Config::Model::Exception::RestrictedElement;
-{
-  $Config::Model::Exception::RestrictedElement::VERSION = '2.047';
-}
-
-sub full_message {
-    my $self = shift;
-
-    my $location = $self->object->name;
-    my $msg      = $self->description;
-    my $element  = $self->element;
-    my $req = $self->object->get_element_property( element => $element, property => 'experience' );
-    $msg .= " '$element' in node '$location':";
-    $msg .= "\n\tNeed privilege '$req' instead of '" . $self->level . "'\n";
-    $msg .= "\t" . $self->info . "\n" if defined $self->info;
-    return $msg;
-}
-
 package Config::Model::Exception::UnavailableElement;
-{
-  $Config::Model::Exception::UnavailableElement::VERSION = '2.047';
-}
+$Config::Model::Exception::UnavailableElement::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
@@ -299,7 +259,6 @@ sub full_message {
     my $function = $self->function;
     my $unavail  = $obj->fetch_element(
         name          => $element,
-        experience    => 'master',
         check         => 'no',
         accept_hidden => 1
     );
@@ -312,9 +271,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::ObsoleteElement;
-{
-  $Config::Model::Exception::ObsoleteElement::VERSION = '2.047';
-}
+$Config::Model::Exception::ObsoleteElement::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
@@ -333,9 +290,8 @@ sub full_message {
 }
 
 package Config::Model::Exception::UnknownElement;
-{
-  $Config::Model::Exception::UnknownElement::VERSION = '2.047';
-}
+$Config::Model::Exception::UnknownElement::VERSION = '2.059';
+
 use Carp;
 
 sub full_message {
@@ -344,34 +300,32 @@ sub full_message {
     my $obj = $self->object;
 
     confess "Exception::UnknownElement: object is ", ref($obj), ". Expected a node"
-      unless $obj->isa('Config::Model::Node')
-      || $obj->isa('Config::Model::WarpedNode');
+        unless $obj->isa('Config::Model::Node')
+        || $obj->isa('Config::Model::WarpedNode');
 
-    my $min_experience = $self->min_experience || 'master';
     my $class_name = $obj->config_class_name;
 
     # class_name is undef if the warped_node is warped out
     my @elements;
     @elements = $obj->get_element_name(
         class => $class_name,
-        for   => $min_experience
     ) if defined $class_name;
 
     my $msg = '';
     $msg .= "In " . $self->where . ": "
-      if defined $self->where;
+        if defined $self->where;
 
     $msg .= "(function '" . $self->function . "') "
-      if defined $self->function;
+        if defined $self->function;
 
     $msg = "object '" . $obj->name . "' error: " unless $msg;
 
     $msg .= $self->description . " '" . $self->element . "'.";
 
     $msg .=
-        " Either your file has an error or $class_name model is lagging behind. "
-      . "In the latter case, please submit a bug report or fix the model. See cme man "
-      . "page for details.\n";
+          " Either your file has an error or $class_name model is lagging behind. "
+        . "In the latter case, please submit a bug report or fix the model. See cme man "
+        . "page for details.\n";
 
     if (@elements) {
         $msg .= "\tExpected elements: '" . join( "','", @elements ) . "'\n";
@@ -392,10 +346,10 @@ sub full_message {
 
         if ( $parent->element_type($element_name) eq 'warped_node' ) {
             $msg .= "\t"
-              . $parent->fetch_element(
+                . $parent->fetch_element(
                 name => $element_name,
-                qw/experience master check no accept_hidden 1/
-              )->warp_error;
+                qw/master check no accept_hidden 1/
+                )->warp_error;
         }
     }
 
@@ -405,40 +359,35 @@ sub full_message {
 }
 
 package Config::Model::Exception::UnknownId;
-{
-  $Config::Model::Exception::UnknownId::VERSION = '2.047';
-}
+$Config::Model::Exception::UnknownId::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
 
     my $obj = $self->object;
-    my $min_experience = $self->min_experience || 'master';
 
     my $element = $self->element;
     my $id_str = "'" . join( "','", $obj->fetch_all_indexes() ) . "'";
 
     my $msg = '';
     $msg .= "In function " . $self->function . ": "
-      if defined $self->function;
+        if defined $self->function;
 
     $msg .= "In " . $self->where . ": "
-      if defined $self->where;
+        if defined $self->where;
 
     $msg .=
-        $self->description . " '"
-      . $self->id() . "'"
-      . " for element '"
-      . $obj->location
-      . "'\n\texpected: $id_str\n";
+          $self->description . " '"
+        . $self->id() . "'"
+        . " for element '"
+        . $obj->location
+        . "'\n\texpected: $id_str\n";
 
     return $msg;
 }
 
 package Config::Model::Exception::WrongType;
-{
-  $Config::Model::Exception::WrongType::VERSION = '2.047';
-}
+$Config::Model::Exception::WrongType::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
@@ -447,38 +396,34 @@ sub full_message {
 
     my $msg = '';
     $msg .= "In function " . $self->function . ": "
-      if defined $self->function;
+        if defined $self->function;
 
     $msg .=
-        $self->description
-      . " for element '"
-      . $obj->location
-      . "'\n\tgot type '"
-      . $self->got_type
-      . "', expected '"
-      . $self->expected_type . "' "
-      . $self->info . "\n";
+          $self->description
+        . " for element '"
+        . $obj->location
+        . "'\n\tgot type '"
+        . $self->got_type
+        . "', expected '"
+        . $self->expected_type . "' "
+        . $self->info . "\n";
 
     return $msg;
 }
 
-package Config::Model::Exception::ConfigFile::Missing ;
-{
-  $Config::Model::Exception::ConfigFile::Missing::VERSION = '2.047';
-}
+package Config::Model::Exception::ConfigFile::Missing;
+$Config::Model::Exception::ConfigFile::Missing::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
 
-    my $msg = "Error: cannot find configuration file ". join ' or ', @{$self->tried_files};
+    my $msg = "Error: cannot find configuration file " . join ' or ', @{ $self->tried_files };
 
     return $msg . "\n";
 }
 
 package Config::Model::Exception::Xml;
-{
-  $Config::Model::Exception::Xml::VERSION = '2.047';
-}
+$Config::Model::Exception::Xml::VERSION = '2.059';
 
 sub full_message {
     my $self = shift;
@@ -487,7 +432,7 @@ sub full_message {
     my $msg = $self->message;
 
     $msg .= "\n\t" . join( "\n\t", map ( $_->xpath_message, $self->object->errors ) )
-      if defined $self->object;
+        if defined $self->object;
 
     return $msg . "\n";
 }
@@ -508,7 +453,7 @@ Config::Model::Exception - Exception mechanism for configuration model
 
 =head1 VERSION
 
-version 2.047
+version 2.059
 
 =head1 SYNOPSIS
 
@@ -569,7 +514,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dominique Dumont.
+This software is Copyright (c) 2014 by Dominique Dumont.
 
 This is free software, licensed under:
 
